# Terminal-Overflow

The command line is a powerful tool, but is not very user friendly. This project will give you an edge and save you time when you need to find, put together, and run a command. Features:

* Visual Experience
* Mouse & keyboard navigation
* Customise and link helper containers
* Leverage multiple data sources

<!--
<a href="https://terminaloverflow.com/framework/" target="_blank">Watch the video demo here (15 seconds).</a>
-->
----
## Content
* QuickStart
* Demo
* Contact Info

----
## Quick Start

1. **Install:**
  ```bash
  pip install terminaloverflow
  ```
2. **Run:**
  ```bash
  terminaloverflow
  ```

----
## Overview Diagram
<img  src="./docs/gcloud_terminal_overflow.png" />
----
## Contact

David Zentner dazcode@gmail.com